==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/pl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Czy chcesz dodać zdalne udostępnienie {name} od {owner}@{remote}?",
    "Remote share" : "Zdalne udostępnienie",
    "Remote share password" : "Hasło zdalnego udostępnienia",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalne udostępnienie",
    "Copy" : "Kopiuj",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Brak wsparcia!",
    "Press ⌘-C to copy." : "Wciśnij ⌘-C by skopiować.",
    "Press Ctrl-C to copy." : "Wciśnij Ctrl-C by skopiować.",
    "Invalid Federated Cloud ID" : "Nieprawidłowe ID Chmury Federacyjnej",
    "Server to server sharing is not enabled on this server" : "Serwer do udostępniania serwera nie jest włączony na tym serwerze",
    "Couldn't establish a federated share." : "Nie udało się ustalić Federacyjnego udostępnienia.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nie udało się ustalić Federacyjnego udostępnienia, może być błędne hasło.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Wysłano żądanie Udostępniania Federacyjnego, otrzymasz zaproszenie. Sprawdzaj swoje powiadomienia.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nie można ustanowić współdzielenia federacyjnego. Wygląda na to, że serwer wybrany do udostępnienia jest zbyt stary (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Niedozwolone jest wysyłanie grupowych udostępnień federacyjnych z tego serwera.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Udostępnianie %1$s nie powiodło się, ponieważ ten element jest już współdzielony z %2$s",
    "Not allowed to create a federated share with the same user" : "Nie można tworzyć udostępniania federacyjnego z tym samym użytkownikiem",
    "File is already shared with %s" : "Plik jest już współdzielony z %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Udostępnianie %1$s nie powiodło się, nie można odnaleźć %2$s, być może serwer jest nieosiągalny lub używa certyfikatu z podpisem własnym.",
    "Could not find share" : "Nie można znaleźć powiązania",
    "Federated sharing" : "Udostępnianie Federacyjne",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Otrzymałeś \"%3$s\" zdalne udostępnienie od %4$s (%1$s) (w imieniu %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Otrzymałeś {share} zdalne udostępnienie od {user} (w imieniu {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Otrzymałeś \"%3$s\" zdalne udostępnienie od %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Otrzymałeś {share} zdalne udostępnienie od {user}",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Udostępnij mi poprzez mój ID #Nextcloud Chmury Federacyjnej, zobacz %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Udostępnij mi poprzez mój ID #Nextcloud Chmury Federacyjnej",
    "Sharing" : "Udostępnianie",
    "Federated file sharing" : "Federacyjne udostępnianie plików",
    "Provide federated file sharing across servers" : "Zezwól na federacyjne udostępnianie plików na serwerach",
    "Federated Cloud Sharing" : "Udostępnianie Chmury Federacyjnej",
    "Open documentation" : "Otwórz dokumentację",
    "Adjust how people can share between servers." : "Dostosuj w jaki sposób można udostępniać serwery.",
    "Allow users on this server to send shares to other servers. This option also allows WebDAV access to public shares" : "Zezwalaj użytkownikom na tym serwerze na wysłanie udostępnień do innych serwerów. Ta opcja umożliwia również dostęp WebDAV do udostępnień publicznych",
    "Allow users on this server to receive shares from other servers" : "Zezwalaj użytkownikom na tym serwerze do otrzymania udostępnień z innych serwerów",
    "Allow users on this server to send shares to groups on other servers" : "Zezwalaj użytkownikom na tym serwerze na udostępnianie dla grup na innych serwerach",
    "Allow users on this server to receive group shares from other servers" : "Zezwalaj użytkownikom na tym serwerze na przyjmowanie udostępnienia od grupy z innych serwerów",
    "Search global and public address book for users" : "Wyszukiwarka globalnej i publicznej książki adresowej dla użytkowników",
    "Allow users to publish their data to a global and public address book" : "Zezwalaj użytkownikom publikować swoje dane w globalnej i publicznej książce adresowej",
    "Federated Cloud" : "Chmura Federacyjna",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Możesz współdzielić z każdym, kto używa serwera Nextcloud lub innych serwerów i usług kompatybilnych z Open Cloud Mesh (OCM). Wystarczy, że wpiszesz ID Chmury Federacyjnej w oknie udostępniania, według przykładu: osoba@chmura.przykładowa.com",
    "Your Federated Cloud ID:" : "Twoje ID Chmury Federacyjnej:",
    "Share it so your friends can share files with you:" : "Udostępnij, aby Twoi znajomi mogli współdzielić pliki z Tobą:",
    "Add to your website" : "Dodaj do swojej strony",
    "Share with me via Nextcloud" : "Udostępnij mi za pomocą Nextcloud",
    "HTML Code:" : "Kod HTML:",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Otrzymałeś \"%3$s\" zdalne udostępnienie od %1$s (w imieniu %2$s)",
    "You received \"%3$s\" as a remote share from %1$s" : "Otrzymałeś \"%3$s\" zdalne udostępnienie od %1$s",
    "Allow users on this server to send shares to other servers" : "Zezwalaj użytkownikom na tym serwerze na wysłanie udostępnień do innych serwerów"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-21.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/pl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Czy chcesz dodać zdalne udostępnienie {name} od {owner}@{remote}?",
    "Remote share" : "Zdalne udostępnienie",
    "Remote share password" : "Hasło zdalnego udostępnienia",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalne udostępnienie",
    "Copy" : "Kopiuj",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Brak wsparcia!",
    "Press ⌘-C to copy." : "Wciśnij ⌘-C by skopiować.",
    "Press Ctrl-C to copy." : "Wciśnij Ctrl-C by skopiować.",
    "Invalid Federated Cloud ID" : "Nieprawidłowe ID Chmury Federacyjnej",
    "Server to server sharing is not enabled on this server" : "Serwer do udostępniania serwera nie jest włączony na tym serwerze",
    "Couldn't establish a federated share." : "Nie udało się ustalić Federacyjnego udostępnienia.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nie udało się ustalić Federacyjnego udostępnienia, może być błędne hasło.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Wysłano żądanie Udostępniania Federacyjnego, otrzymasz zaproszenie. Sprawdzaj swoje powiadomienia.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nie można ustanowić współdzielenia federacyjnego. Wygląda na to, że serwer wybrany do udostępnienia jest zbyt stary (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Niedozwolone jest wysyłanie grupowych udostępnień federacyjnych z tego serwera.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Udostępnianie %1$s nie powiodło się, ponieważ ten element jest już udostępniony użytkownikowi %2$s",
    "Not allowed to create a federated share with the same user" : "Nie można tworzyć udostępniania federacyjnego z tym samym użytkownikiem",
    "Federated shares require read permissions" : "Udostępnienia federacyjne wymagają uprawnień do odczytu",
    "File is already shared with %s" : "Plik jest już udostępniony dla %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Udostępnianie %1$s nie powiodło się, nie można odnaleźć %2$s, być może serwer jest nieosiągalny lub używa certyfikatu z podpisem własnym.",
    "Could not find share" : "Nie można znaleźć powiązania",
    "Federated sharing" : "Udostępnianie Federacyjne",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Otrzymałeś \"%3$s\" zdalne udostępnienie od %4$s (%1$s) (w imieniu %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Otrzymałeś {share} zdalne udostępnienie od {user} (w imieniu {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Otrzymałeś \"%3$s\" zdalne udostępnienie od %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Otrzymałeś {share} zdalne udostępnienie od {user}",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Udostępnij mi poprzez mój ID #Nextcloud Chmury Federacyjnej, zobacz %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Udostępnij mi poprzez mój ID #Nextcloud Chmury Federacyjnej",
    "Sharing" : "Udostępnianie",
    "Federated file sharing" : "Federacyjne udostępnianie plików",
    "Provide federated file sharing across servers" : "Zezwól na federacyjne udostępnianie plików na serwerach",
    "Federated Cloud Sharing" : "Udostępnianie Chmury Federacyjnej",
    "Open documentation" : "Otwórz dokumentację",
    "Adjust how people can share between servers." : "Dostosuj w jaki sposób można udostępniać serwery.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Zezwalaj użytkownikom na tym serwerze na wysłanie udostępnień do innych serwerów (opcja ta umożliwia również dostęp WebDAV do udostępnień publicznych)",
    "Allow users on this server to receive shares from other servers" : "Zezwalaj użytkownikom na tym serwerze do otrzymania udostępnień z innych serwerów",
    "Allow users on this server to send shares to groups on other servers" : "Zezwalaj użytkownikom na tym serwerze na udostępnianie dla grup na innych serwerach",
    "Allow users on this server to receive group shares from other servers" : "Zezwalaj użytkownikom na tym serwerze na przyjmowanie udostępnienia od grupy z innych serwerów",
    "Search global and public address book for users" : "Wyszukiwarka globalnej i publicznej książki adresowej dla użytkowników",
    "Allow users to publish their data to a global and public address book" : "Zezwalaj użytkownikom publikować swoje dane w globalnej i publicznej książce adresowej",
    "Federated Cloud" : "Chmura Federacyjna",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Możesz współdzielić z każdym, kto używa serwera Nextcloud lub innych serwerów i usług kompatybilnych z Open Cloud Mesh (OCM). Wystarczy, że wpiszesz ID Chmury Federacyjnej w oknie udostępniania, według przykładu: osoba@chmura.przykładowa.com",
    "Your Federated Cloud ID:" : "Twoje ID Chmury Federacyjnej:",
    "Share it so your friends can share files with you:" : "Udostępnij, aby Twoi znajomi mogli współdzielić pliki z Tobą:",
    "Add to your website" : "Dodaj do swojej strony",
    "Share with me via Nextcloud" : "Udostępnij mi za pomocą Nextcloud",
    "HTML Code:" : "Kod HTML:",
    "Allow users on this server to send shares to other servers" : "Zezwalaj użytkownikom na tym serwerze na wysłanie udostępnień do innych serwerów"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
